@@ -99,7 +99,14 @@ class bngmodel:
         """
         write the model to str
         """
-        model_str = "begin model\n"
+        model_str = ""
+        # gotta check for "before model" type actions
+        if hasattr(self, "actions"):
+            ablock = getattr(self, "actions")
+            if len(ablock.before_model) > 0:
+                for baction in ablock.before_model:
+                    model_str += str(baction) + "\n"
+        model_str += "begin model\n"
         for block in self.block_order:
             # ensure we didn't get new items into a
             # previously inactive block, if we did
@@ -251,8 +258,8 @@ class bngmodel:
             # we need to add writeSBML action for now
             curr_actions = copy.deepcopy(self.actions)
             self.actions.clear_actions()
-            self.add_action("generate_network", [("overwrite", 1)])
-            self.add_action("writeSBML", [])
+            self.add_action("generate_network", {"overwrite": 1})
+            self.add_action("writeSBML", {})
             # temporary file
             with TemporaryFile(mode="w+") as tpath:
                 # write the sbml
